from instabotnet import execute
import os
import yaml
import json

path = os.environ['SCRIPT']

def load(path):
    with open(path) as f:
        return f.read()

class Dumper(yaml.Dumper):
    def increase_indent(self, flow=False, indentless=False):
        return super(Dumper, self).increase_indent(flow, False)

# print(yaml.dump(dict(**os.environ), Dumper=Dumper, default_flow_style=False))

data = execute(
    load(path),
    os.environ
)
print('returned data:')
print(json.dumps(dict(**data), indent=4))



import sys

import time
import os.path
sys.path.append( os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
from instabotnet import execute
import yaml
import json

class dotdict(dict):
    """dot.notation access to dictionary attributes"""
    __getattr__ = dict.get
    __setattr__ = dict.__setitem__
    __delattr__ = dict.__delitem__


def load(path):
    with open(path) as f:
        return f.read()

try:
    from . import credentials

except Exception:
    class credentials:
        USER = os.environ.get('IG_USERNAME')
        PASS = os.environ.get('IG_PASSWORD')



tests = [
    # 'tests/basic.yml',
    # 'tests/upload_single_post.yml',
    # 'tests/upload_carousel_post.yml',
    # 'tests/upload_video_post.yml',
    # 'tests/delete_last_post.yml',
    # 'tests/print_user_stories.yml',
    # 'tests/scrape_users.yml',
    'tests/print_users_feed.yml',
    # 'tests/message_some_urls.yml',
    # 'tests/repost_routine.yml',
]



class Dumper(yaml.Dumper):
    def increase_indent(self, flow=False, indentless=False):
        return super(Dumper, self).increase_indent(flow, False)

for path in tests:
    print()
    print()
    print()
    print()
    print()
    print()
    config = dotdict(**{
            'USERNAME': credentials.USER,
            'username': credentials.USER,
            'PASSWORD': credentials.PASS,
            'password': credentials.PASS,
            # 'settings': json.load(open(credentials.USER + '_settings.json', 'r')),
            'settings_path': credentials.USER + '_settings.json',
            'competitors': ['instagram'],
            'inspirations': ['archillect.png'],
            'captions': ['hey', 'bruh'],
            'hashtags': ['pizza'],
            'geotags': ['monaco'],
            'comments': ['wow', 'awesome'],
            'proxy': None,

    })
    data = execute(
        load(path),
        config
    )
    # print('data: \n', yaml.dump(data, Dumper=Dumper, default_flow_style=False))

    print('returned data:')
    print(json.dumps(dict(**data), indent=4))
    print('config:')
    print(json.dumps(config, indent=4))
    time.sleep(3)



from xml.etree import ElementTree
import ffmpeg
import os
from random import random

string = """<MPD xmlns=\"urn:mpeg:dash:schema:mpd:2011\" minBufferTime=\"PT1.500S\" type=\"static\" mediaPresentationDuration=\"PT0H1M0.070S\" maxSegmentDuration=\"PT0H0M2.020S\" profiles=\"urn:mpeg:dash:profile:isoff-on-demand:2011,http://dashif.org/
guidelines/dash264\"><Period duration=\"PT0H1M0.070S\"><AdaptationSet segmentAlignment=\"true\" lang=\"und\" subsegmentAlignment=\"true\" subsegmentStartsWithSAP=\"1\"><Representation id=\"17998003366084790ad\" mimeType=\"audio/mp4\" codecs=\"mp4
a.40.2\" audioSamplingRate=\"44100\" startWithSAP=\"1\" bandwidth=\"65964\"><AudioChannelConfiguration schemeIdUri=\"urn:mpeg:dash:23003:3:audio_channel_configuration:2011\" value=\"2\"/><BaseURL>https://scontent-mxp1-1.cdninstagram.com/vp/f9f288
a81a93d67053a34ec8d8c70689/5C7DE945/t50.2886-16/49335811_275270176479795_4112980307395428073_n.mp4?_nc_ht=scontent-mxp1-1.cdninstagram.com</BaseURL><SegmentBase indexRangeExact=\"true\" indexRange=\"840-1243\" FBFirstSegmentRange=\"1244-18490\" F
BSecondSegmentRange=\"18491-34962\"><Initialization range=\"0-839\"/></SegmentBase></Representation></AdaptationSet><AdaptationSet segmentAlignment=\"true\" maxWidth=\"720\" maxHeight=\"900\" maxFrameRate=\"30\" par=\"452:566\" lang=\"und\" subse
gmentAlignment=\"true\" subsegmentStartsWithSAP=\"1\"><Representation id=\"17847729046332851vd\" mimeType=\"video/mp4\" codecs=\"avc1.4D401F\" width=\"452\" height=\"566\" frameRate=\"30\" sar=\"1:1\" startWithSAP=\"1\" bandwidth=\"221953\" FBQua
lityClass=\"sd\" FBQualityLabel=\"452w\"><BaseURL>https://scontent-mxp1-1.cdninstagram.com/vp/8bc67ec8cfe6daf1cd6f47d7ea688f30/5C7E3168/t50.2886-16/50431121_594924300920837_38858319701395766_n.mp4?_nc_ht=scontent-mxp1-1.cdninstagram.com</BaseURL>
<SegmentBase indexRangeExact=\"true\" indexRange=\"910-1301\" FBFirstSegmentRange=\"1302-23553\" FBSecondSegmentRange=\"23554-59460\"><Initialization range=\"0-909\"/></SegmentBase></Representation><Representation id=\"18006495649097946v\" mimeTy
pe=\"video/mp4\" codecs=\"avc1.4D401F\" width=\"284\" height=\"356\" frameRate=\"30\" sar=\"1:1\" startWithSAP=\"1\" bandwidth=\"112707\" FBQualityClass=\"sd\" FBQualityLabel=\"284w\"><BaseURL>https://scontent-mxp1-1.cdninstagram.com/vp/6d5a33c79
169ebc4398c9eca11f552a2/5C7E6F63/t50.2886-16/50259299_231394417748483_5290620231680510418_n.mp4?_nc_ht=scontent-mxp1-1.cdninstagram.com</BaseURL><SegmentBase indexRangeExact=\"true\" indexRange=\"910-1301\" FBFirstSegmentRange=\"1302-13206\" FBSe
condSegmentRange=\"13207-32728\"><Initialization range=\"0-909\"/></SegmentBase></Representation><Representation id=\"17996949475093919v\" mimeType=\"video/mp4\" codecs=\"avc1.4D401F\" width=\"720\" height=\"900\" frameRate=\"30\" sar=\"1:1\" sta
rtWithSAP=\"1\" bandwidth=\"459623\" FBQualityClass=\"hd\" FBQualityLabel=\"720w\"><BaseURL>https://scontent-mxp1-1.cdninstagram.com/vp/1e8900385bef06481f7018388dc98238/5C7E2222/t50.2886-16/50317307_124640905243240_921695025927607707_n.mp4?_nc_ht
=scontent-mxp1-1.cdninstagram.com</BaseURL><SegmentBase indexRangeExact=\"true\" indexRange=\"910-1301\" FBFirstSegmentRange=\"1302-57502\" FBSecondSegmentRange=\"57503-129877\"><Initialization range=\"0-909\"/></SegmentBase></Representation></Ad
aptationSet></Period></MPD>"""

class temporary_write:
        def __init__(self,  data, path=str(random())[3:]):
                self.path = path
                self.data = data
                f = open(self.path, 'a+b')
                f.write(self.data)
                f.close()

        __enter__ = lambda self: self.path
        __exit__ = lambda self, a, b, c: os.remove(self.path)


manifest = string.replace('\n','')

with temporary_write(manifest, path='manifest.mpd') as path:

    (ffmpeg
        .input(manifest, format='dash')
        .output('out.mp4')
        .run()
    )


root = ElementTree.fromstring(manifest)
for a in root.findall('.//{urn:mpeg:dash:schema:mpd:2011}BaseURL'):
    print (a.attrib)
